@@ -89,12 +89,25 @@ class Device(object):
             "awk '{print $1}'",]))
         ips = out.split("\n")
         if out and not out.startswith("127.0.0.1"):
-            self._logger.debug("found IP addresses:" + str(out))
+            self._logger.debug("found IP addresses:" + str(ips))
             return out.split('\n')
         else:
             raise NoIPException("couldn't receive any IP address:'{}'".format(
                 ips))
 
+    @property
+    def mac_addrs(self):
+        """ get a list of all current MAC addresses of device
+        """
+        self._logger.info("retreive MAC addresses")
+        out = self.cmd(" | ".join((
+            "ifconfig -a",
+            "grep HWaddr",
+            "awk '{print $5}'",))
+        macs = out.split("\n")
+        self._logger.debug("found MAC addresses:" + str(macs))
+        return macs
+
     def cmd(self, msg):
         """ Send a :term:`shell command` to the :term:`target device`.
 
